@@ -4,12 +4,14 @@ from django.http import HttpResponse
 
 from httpproxy import settings
 from httpproxy.exceptions import UnkownProxyMode
+from httpproxy.decorators import normalize_request, rewrite_response
  
 
-PROXY_FORMAT = u'http://%s:%d/%s' % (settings.PROXY_DOMAIN, settings.PROXY_PORT, u'%s')
+PROXY_FORMAT = u'http://%s:%d%s' % (settings.PROXY_DOMAIN, settings.PROXY_PORT, u'%s')
 
-def proxy(request, url):
+def proxy(request):
     conn = httplib2.Http()
+    url = request.path
     
     # Optionally provide authentication for server
     try:
@@ -31,9 +33,14 @@ def proxy(request, url):
 if settings.PROXY_MODE is not None:
     proxy_mode = settings.PROXY_MODE
     try:
-        decorator = getattr(__import__(__package__ + '.decorators', fromlist=proxy_mode), proxy_mode)
+        decorator = getattr(__import__('httpproxy' + '.decorators', fromlist=proxy_mode), proxy_mode)
     except AttributeError, e:
-        raise UnkownProxyMode('The proxy mode "%s" could not be found. Please specify a corresponding decorator function in "%s.decorators".' % (proxy_mode, __package__))
+        raise UnkownProxyMode('The proxy mode "%s" could not be found. Please specify a corresponding decorator function in "%s.decorators".' % (proxy_mode, 'httpproxy'))
     else:
         proxy = decorator(proxy)
-    
+
+if settings.PROXY_REWRITE_RESPONSES:
+    proxy = rewrite_response(proxy)
+
+# The request object should always be normalized
+proxy = normalize_request(proxy)
